import { LitElement } from "lit-element";
import Highcharts from "highcharts";
export declare type HighchartsConstructorType = "chart" | "stockChart" | "mapChart" | "ganttChart";
/**
 * @element highcharts-chart
 *
 * @fires load - Event fired after the chart is created. The `detail` arg will hold the created chart
 */
export default class HighchartsWebComponent extends LitElement {
    /**
     * String for constructor method. Official constructors:
     *  - 'chart' for Highcharts charts
     *  - 'stockChart' for Highstock charts
     *  - 'mapChart' for Highmaps charts
     *  - 'ganttChart' for Gantt charts
     */
    constructorType: HighchartsConstructorType;
    /**
     * Used to pass the Highcharts instance after modules are initialized.
     * If not set the component will try to get the Highcharts from window.
     */
    highcharts: typeof Highcharts;
    /**
     * Highcharts chart configuration object.
     * Please refer to the Highcharts (API documentation)[https://api.highcharts.com/highcharts/].
     */
    options: Object;
    /**
     * This wrapper uses chart.update() method to apply new options
     * to the chart when changing the parent component.
     * This option allow to turn off the updating.
     */
    allowChartUpdate: boolean;
    /**
     * Reinitialises the chart on prop update (as oppose to chart.update())
     * useful in some cases but slower than a regular update.
     */
    immutable: boolean;
    /**
     * Array of update()'s function optional arguments.
     * Parameters should be defined in the same order like in
     * native Highcharts function: [redraw, oneToOne, animation].
     * (Here)[https://api.highcharts.com/class-reference/Highcharts.Chart#update] is a more specific description of the parameters.
     */
    updateArgs: [boolean, boolean, boolean];
    private chartContainer;
    private chart;
    firstUpdated(): void;
    updated(): void;
    render(): import("lit-element").TemplateResult;
    private createChart;
    private chartCreated;
    disconnectedCallback(): void;
}
